#[cfg(not(feature = "nostd"))]
mod std_collections;

#[cfg(feature = "slab")]
mod slab;

#[cfg(feature = "smallvec")]
mod smallvec;

#[cfg(feature = "serde_json")]
mod serde_json;

#[cfg(feature = "ijson")]
mod ijson;
